dataframe-0.7.0.0: A fast, safe, and intuitive DataFrame library.
Safe HaskellNone
LanguageHaskell2010

DataFrame.IO.Parquet.Page

Synopsis

Documentation

readNInt32Vec :: Int -> ByteString -> Vector Int32 Source #

Read n Int32 values directly into an unboxed vector (no intermediate list).

readNInt64Vec :: Int -> ByteString -> Vector Int64 Source #

Read n Int64 values directly into an unboxed vector.

readNFloatVec :: Int -> ByteString -> Vector Float Source #

Read n Float values directly into an unboxed vector.

readNDoubleVec :: Int -> ByteString -> Vector Double Source #

Read n Double values directly into an unboxed vector.