dataframe-1.0.0.1: A fast, safe, and intuitive DataFrame library.
Safe HaskellNone
LanguageHaskell2010

DataFrame.IO.Parquet.Thrift

Synopsis

Documentation

data KeyValue Source #

Constructors

KeyValue 

Fields

Instances

Instances details
Show KeyValue Source # 
Instance details

Defined in DataFrame.IO.Parquet.Thrift

Eq KeyValue Source # 
Instance details

Defined in DataFrame.IO.Parquet.Thrift

data TType Source #

Constructors

STOP 
BOOL 
BYTE 
I16 
I32 
I64 
I96 
FLOAT 
DOUBLE 
STRING 
LIST 
SET 
MAP 
STRUCT 
UUID 

Instances

Instances details
Show TType Source # 
Instance details

Defined in DataFrame.IO.Parquet.Thrift

Methods

showsPrec :: Int -> TType -> ShowS #

show :: TType -> String #

showList :: [TType] -> ShowS #

Eq TType Source # 
Instance details

Defined in DataFrame.IO.Parquet.Thrift

Methods

(==) :: TType -> TType -> Bool #

(/=) :: TType -> TType -> Bool #

readMetadataByHandleMetaSize :: FileBufferedOrSeekable -> Int -> IO FileMetadata Source #

This avoids reading entire bytestring at once: it uses the seekable handle seeks it to the end of the file to read the metadata

readMetadata :: ByteString -> Int -> IO FileMetadata Source #

metadata starts from (L - 8 - meta_size) to L - 8 - 1.