dataframe-0.7.0.0: A fast, safe, and intuitive DataFrame library.
Safe HaskellNone
LanguageHaskell2010

DataFrame.Lazy.Internal.PhysicalPlan

Synopsis

Documentation

data ScanConfig Source #

Scan-level configuration: batch size, separator, optional pushdowns.

Instances

Instances details
Show ScanConfig Source # 
Instance details

Defined in DataFrame.Lazy.Internal.PhysicalPlan

data PhysicalPlan Source #

Physical plan: every node carries enough information for the executor to allocate resources and choose algorithms without further analysis.

Instances

Instances details
Show PhysicalPlan Source # 
Instance details

Defined in DataFrame.Lazy.Internal.PhysicalPlan