dataframe-0.7.0.0: A fast, safe, and intuitive DataFrame library.
Safe HaskellNone
LanguageHaskell2010

DataFrame.Operations.Aggregation

Synopsis

Documentation

groupBy :: [Text] -> DataFrame -> GroupedDataFrame Source #

O(k * n) groups the dataframe by the given rows aggregating the remaining rows into vector that should be reduced later.

buildRowToGroup :: Int -> Vector Int -> Vector Int -> Vector Int Source #

Build the rowToGroup lookup vector from valueIndices and offsets. rowToGroup[i] = k means row i belongs to group k.

aggregate :: [NamedExpr] -> GroupedDataFrame -> DataFrame Source #

Aggregate a grouped dataframe using the expressions given. All ungrouped columns will be dropped.

distinct :: DataFrame -> DataFrame Source #

Filter out all non-unique values in a dataframe.