dataframe-0.7.0.0: A fast, safe, and intuitive DataFrame library.
Safe HaskellNone
LanguageHaskell2010

DataFrame.Synthesis

Synopsis

Documentation

equivalent :: DataFrame -> Expr Double -> Expr Double -> Bool Source #

Checks if two programs generate the same outputs given all the same inputs.

synthesizeFeatureExpr Source #

Arguments

:: Text

Target expression

-> BeamConfig 
-> DataFrame 
-> Either String (Expr Double) 

fitClassifier Source #

Arguments

:: Text

Target expression

-> Int

Depth of search (Roughly, how many terms in the final expression)

-> Int

Beam size - the number of candidate expressions to consider at a time.

-> DataFrame 
-> Either String (Expr Int) 

fitRegression Source #

Arguments

:: Text

Target expression

-> Int

Depth of search (Roughly, how many terms in the final expression)

-> Int

Beam size - the number of candidate expressions to consider at a time.

-> DataFrame 
-> Either String (Expr Double) 

beamSearch Source #

Arguments

:: DataFrame 
-> BeamConfig

Parameters of the beam search.

-> TypedColumn Double

Examples

-> [Expr Double]

Constants

-> [Expr Bool]

Conditions

-> [Expr Double]

Programs

-> Maybe (Expr Double)