| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
DataFrame.IO.Parquet.Thrift
Synopsis
- data SchemaElement = SchemaElement {}
- createParquetSchema :: DataFrame -> [SchemaElement]
- data KeyValue = KeyValue {}
- data FileMetadata = FileMetaData {}
- data TType
- haskellToTType :: Typeable a => TType
- defaultMetadata :: FileMetadata
- data ColumnMetaData = ColumnMetaData {
- columnType :: ParquetType
- columnEncodings :: [ParquetEncoding]
- columnPathInSchema :: [String]
- columnCodec :: CompressionCodec
- columnNumValues :: Int64
- columnTotalUncompressedSize :: Int64
- columnTotalCompressedSize :: Int64
- columnKeyValueMetadata :: [KeyValue]
- columnDataPageOffset :: Int64
- columnIndexPageOffset :: Int64
- columnDictionaryPageOffset :: Int64
- columnStatistics :: ColumnStatistics
- columnEncodingStats :: [PageEncodingStats]
- bloomFilterOffset :: Int64
- bloomFilterLength :: Int32
- columnSizeStatistics :: SizeStatistics
- columnGeospatialStatistics :: GeospatialStatistics
- data ColumnChunk = ColumnChunk {
- columnChunkFilePath :: String
- columnChunkMetadataFileOffset :: Int64
- columnMetaData :: ColumnMetaData
- columnChunkOffsetIndexOffset :: Int64
- columnChunkOffsetIndexLength :: Int32
- columnChunkColumnIndexOffset :: Int64
- columnChunkColumnIndexLength :: Int32
- cryptoMetadata :: ColumnCryptoMetadata
- encryptedColumnMetadata :: ByteString
- data RowGroup = RowGroup {}
- defaultSchemaElement :: SchemaElement
- emptyColumnMetadata :: ColumnMetaData
- emptyColumnChunk :: ColumnChunk
- emptyKeyValue :: KeyValue
- emptyRowGroup :: RowGroup
- compactBooleanTrue :: Word8
- compactI32 :: Word8
- compactI64 :: Word8
- compactDouble :: Word8
- compactBinary :: Word8
- compactList :: Word8
- compactStruct :: Word8
- toTType :: Word8 -> TType
- readField :: ByteString -> IORef Int -> Int16 -> IO (Maybe (TType, Int16))
- skipToStructEnd :: ByteString -> IORef Int -> IO ()
- skipFieldData :: TType -> ByteString -> IORef Int -> IO ()
- skipList :: ByteString -> IORef Int -> IO ()
- readMetadataByHandleMetaSize :: FileBufferedOrSeekable -> Int -> IO FileMetadata
- readMetadata :: ByteString -> Int -> IO FileMetadata
- readFileMetaData :: FileMetadata -> ByteString -> IORef Int -> Int16 -> IO FileMetadata
- readSchemaElement :: SchemaElement -> ByteString -> IORef Int -> Int16 -> IO SchemaElement
- readRowGroup :: RowGroup -> ByteString -> IORef Int -> Int16 -> IO RowGroup
- readColumnChunk :: ColumnChunk -> ByteString -> IORef Int -> Int16 -> IO ColumnChunk
- readColumnMetadata :: ColumnMetaData -> ByteString -> IORef Int -> Int16 -> IO ColumnMetaData
- readEncryptionAlgorithm :: ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm
- readColumnOrder :: ByteString -> IORef Int -> Int16 -> IO ColumnOrder
- readAesGcmCtrV1 :: EncryptionAlgorithm -> ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm
- readAesGcmV1 :: EncryptionAlgorithm -> ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm
- readTypeOrder :: ByteString -> IORef Int -> Int16 -> IO ColumnOrder
- readKeyValue :: KeyValue -> ByteString -> IORef Int -> Int16 -> IO KeyValue
- readPageEncodingStats :: PageEncodingStats -> ByteString -> IORef Int -> Int16 -> IO PageEncodingStats
- readParquetEncoding :: ByteString -> IORef Int -> Int16 -> IO ParquetEncoding
- readStatistics :: ColumnStatistics -> ByteString -> IORef Int -> Int16 -> IO ColumnStatistics
- readSizeStatistics :: SizeStatistics -> ByteString -> IORef Int -> Int16 -> IO SizeStatistics
- footerSize :: Int
- toIntegralType :: Int32 -> TType
- readLogicalType :: LogicalType -> ByteString -> IORef Int -> Int16 -> IO LogicalType
- readIntType :: Int8 -> Bool -> ByteString -> IORef Int -> Int16 -> IO LogicalType
- readDecimalType :: Int32 -> Int32 -> ByteString -> IORef Int -> Int16 -> IO LogicalType
- readTimeType :: Bool -> TimeUnit -> ByteString -> IORef Int -> Int16 -> IO LogicalType
- readTimestampType :: Bool -> TimeUnit -> ByteString -> IORef Int -> Int16 -> IO LogicalType
- readUnit :: TimeUnit -> ByteString -> IORef Int -> Int16 -> IO TimeUnit
Documentation
data SchemaElement Source #
Constructors
| SchemaElement | |
Fields
| |
Instances
| Show SchemaElement Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods showsPrec :: Int -> SchemaElement -> ShowS # show :: SchemaElement -> String # showList :: [SchemaElement] -> ShowS # | |
| Eq SchemaElement Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods (==) :: SchemaElement -> SchemaElement -> Bool # (/=) :: SchemaElement -> SchemaElement -> Bool # | |
createParquetSchema :: DataFrame -> [SchemaElement] Source #
data FileMetadata Source #
Constructors
| FileMetaData | |
Fields
| |
Instances
| Show FileMetadata Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods showsPrec :: Int -> FileMetadata -> ShowS # show :: FileMetadata -> String # showList :: [FileMetadata] -> ShowS # | |
| Eq FileMetadata Source # | |
Defined in DataFrame.IO.Parquet.Thrift | |
haskellToTType :: Typeable a => TType Source #
data ColumnMetaData Source #
Constructors
Instances
| Show ColumnMetaData Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods showsPrec :: Int -> ColumnMetaData -> ShowS # show :: ColumnMetaData -> String # showList :: [ColumnMetaData] -> ShowS # | |
| Eq ColumnMetaData Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods (==) :: ColumnMetaData -> ColumnMetaData -> Bool # (/=) :: ColumnMetaData -> ColumnMetaData -> Bool # | |
data ColumnChunk Source #
Constructors
Instances
| Show ColumnChunk Source # | |
Defined in DataFrame.IO.Parquet.Thrift Methods showsPrec :: Int -> ColumnChunk -> ShowS # show :: ColumnChunk -> String # showList :: [ColumnChunk] -> ShowS # | |
| Eq ColumnChunk Source # | |
Defined in DataFrame.IO.Parquet.Thrift | |
Constructors
| RowGroup | |
Fields
| |
compactI32 :: Word8 Source #
compactI64 :: Word8 Source #
compactList :: Word8 Source #
skipToStructEnd :: ByteString -> IORef Int -> IO () Source #
skipFieldData :: TType -> ByteString -> IORef Int -> IO () Source #
readMetadataByHandleMetaSize :: FileBufferedOrSeekable -> Int -> IO FileMetadata Source #
This avoids reading entire bytestring at once: it uses the seekable handle seeks it to the end of the file to read the metadata
readMetadata :: ByteString -> Int -> IO FileMetadata Source #
metadata starts from (L - 8 - meta_size) to L - 8 - 1.
readFileMetaData :: FileMetadata -> ByteString -> IORef Int -> Int16 -> IO FileMetadata Source #
readSchemaElement :: SchemaElement -> ByteString -> IORef Int -> Int16 -> IO SchemaElement Source #
readRowGroup :: RowGroup -> ByteString -> IORef Int -> Int16 -> IO RowGroup Source #
readColumnChunk :: ColumnChunk -> ByteString -> IORef Int -> Int16 -> IO ColumnChunk Source #
readColumnMetadata :: ColumnMetaData -> ByteString -> IORef Int -> Int16 -> IO ColumnMetaData Source #
readEncryptionAlgorithm :: ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm Source #
readColumnOrder :: ByteString -> IORef Int -> Int16 -> IO ColumnOrder Source #
readAesGcmCtrV1 :: EncryptionAlgorithm -> ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm Source #
readAesGcmV1 :: EncryptionAlgorithm -> ByteString -> IORef Int -> Int16 -> IO EncryptionAlgorithm Source #
readTypeOrder :: ByteString -> IORef Int -> Int16 -> IO ColumnOrder Source #
readKeyValue :: KeyValue -> ByteString -> IORef Int -> Int16 -> IO KeyValue Source #
readPageEncodingStats :: PageEncodingStats -> ByteString -> IORef Int -> Int16 -> IO PageEncodingStats Source #
readParquetEncoding :: ByteString -> IORef Int -> Int16 -> IO ParquetEncoding Source #
readStatistics :: ColumnStatistics -> ByteString -> IORef Int -> Int16 -> IO ColumnStatistics Source #
readSizeStatistics :: SizeStatistics -> ByteString -> IORef Int -> Int16 -> IO SizeStatistics Source #
footerSize :: Int Source #
toIntegralType :: Int32 -> TType Source #
readLogicalType :: LogicalType -> ByteString -> IORef Int -> Int16 -> IO LogicalType Source #
readIntType :: Int8 -> Bool -> ByteString -> IORef Int -> Int16 -> IO LogicalType Source #
readDecimalType :: Int32 -> Int32 -> ByteString -> IORef Int -> Int16 -> IO LogicalType Source #
readTimeType :: Bool -> TimeUnit -> ByteString -> IORef Int -> Int16 -> IO LogicalType Source #
readTimestampType :: Bool -> TimeUnit -> ByteString -> IORef Int -> Int16 -> IO LogicalType Source #