| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
DataFrame.Operations.Aggregation
Synopsis
- groupBy :: [Text] -> DataFrame -> GroupedDataFrame
- buildRowToGroup :: Int -> Vector Int -> Vector Int -> Vector Int
- changingPoints :: Vector (Int, Int) -> Vector Int
- computeRowHashes :: [Int] -> DataFrame -> Vector Int
- aggregate :: [NamedExpr] -> GroupedDataFrame -> DataFrame
- selectIndices :: Vector Int -> DataFrame -> DataFrame
- distinct :: DataFrame -> DataFrame
Documentation
groupBy :: [Text] -> DataFrame -> GroupedDataFrame Source #
O(k * n) groups the dataframe by the given rows aggregating the remaining rows into vector that should be reduced later.
buildRowToGroup :: Int -> Vector Int -> Vector Int -> Vector Int Source #
Build the rowToGroup lookup vector from valueIndices and offsets. rowToGroup[i] = k means row i belongs to group k.