| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
DataFrame.Operations.Aggregation
Synopsis
Documentation
groupBy :: [Text] -> DataFrame -> GroupedDataFrame Source #
O(k * n) groups the dataframe by the given rows aggregating the remaining rows into vector that should be reduced later.