| Safe Haskell | None |
|---|---|
| Language | Haskell2010 |
DataFrame.Operations.Typing
Synopsis
- type DateFormat = String
- data ParseOptions = ParseOptions {
- missingValues :: [Text]
- sampleSize :: Int
- parseSafe :: Bool
- parseDateFormat :: DateFormat
- defaultParseOptions :: ParseOptions
- parseDefaults :: ParseOptions -> DataFrame -> DataFrame
- parseDefault :: ParseOptions -> Column -> Column
- parseFromExamples :: ParseOptions -> Vector Text -> Column
- handleBoolAssumption :: Vector (Maybe Text) -> Column
- handleIntAssumption :: Vector (Maybe Text) -> Column
- handleDoubleAssumption :: Vector (Maybe Text) -> Column
- handleDateAssumption :: DateFormat -> Vector (Maybe Text) -> Column
- handleTextAssumption :: Vector (Maybe Text) -> Column
- handleNoAssumption :: DateFormat -> Vector (Maybe Text) -> Column
- convertNullish :: [Text] -> Text -> Maybe Text
- convertOnlyEmpty :: Text -> Maybe Text
- parseTimeOpt :: DateFormat -> Text -> Maybe Day
- unsafeParseTime :: DateFormat -> Text -> Day
- hasNullValues :: Eq a => Vector (Maybe a) -> Bool
- vecSameConstructor :: Vector (Maybe a) -> Vector (Maybe b) -> Bool
- makeParsingAssumption :: DateFormat -> Vector (Maybe Text) -> ParsingAssumption
- data ParsingAssumption
- parseWithTypes :: Bool -> Map Text SchemaType -> DataFrame -> DataFrame
- readAsMaybe :: Read a => String -> Maybe a
- readAsEither :: Read a => String -> a
Documentation
type DateFormat = String Source #
data ParseOptions Source #
Options controlling how text columns are parsed into typed values.
Constructors
| ParseOptions | |
Fields
| |
defaultParseOptions :: ParseOptions Source #
Sensible out-of-the-box parse options: infer from the first 100 rows, treat common nullish strings as missing, and expect ISO 8601 dates.
parseDefaults :: ParseOptions -> DataFrame -> DataFrame Source #
parseDefault :: ParseOptions -> Column -> Column Source #
parseFromExamples :: ParseOptions -> Vector Text -> Column Source #
handleDateAssumption :: DateFormat -> Vector (Maybe Text) -> Column Source #
handleNoAssumption :: DateFormat -> Vector (Maybe Text) -> Column Source #
parseTimeOpt :: DateFormat -> Text -> Maybe Day Source #
unsafeParseTime :: DateFormat -> Text -> Day Source #
makeParsingAssumption :: DateFormat -> Vector (Maybe Text) -> ParsingAssumption Source #
data ParsingAssumption Source #
parseWithTypes :: Bool -> Map Text SchemaType -> DataFrame -> DataFrame Source #
readAsEither :: Read a => String -> a Source #